README
====

- 待完成

适配window和mac系统

对接接口，上传数据

对接GUI

- 功能

对APP进行滑动点击操作后，收集应用的错误日志及性能数据（cpu,memery）

- 安装

```shell
pip install monkeyrun
```

- 执行

```python
from monkeyrun import run

run.run(device=devices, fpath=fpath, scheme=scheme, activity=activity, m=5)
```

- 参数解释

```markdown
run the monkey tast
:param device: the devices of android
:param fpath: the path of apk package
:param scheme: the scheme of your business line
:param activity: the activity of you scheme
:param d: day
:param h: hour
:param m: minus
:param s: second
:return: None
```

- LOG

执行log生成于你的执行目录，log/*.log

